@@ -15,7 +15,7 @@ import yaml
 # mine
 import utils
 import preprocessing
-import HandwrittenData
+import hwrt.HandwrittenData as HandwrittenData
 
 
 def main(folder):
